==> mcu_plus_sdk_am64x_07_03_00_19_docs_only.tar.xz: mcu_plus_sdk_am64x_07_03_00_19_docs_only/docs/api_guide_am64x/group__KERNEL__DPL__CLOCK.js <==
var group__KERNEL__DPL__CLOCK =
[
    [ "ClockP_Object", "structClockP__Object.html", [
      [ "rsv", "structClockP__Object.html#a611ac2d2464c1b15a69ca5c7438da7de", null ]
    ] ],
    [ "ClockP_Config", "structClockP__Config.html", [
      [ "timerBaseAddr", "structClockP__Config.html#ad5d27f698d006879055639d843b1a917", null ],
      [ "timerHwiIntNum", "structClockP__Config.html#a2bea5ba5e3f70226fe86fa4a89f602d1", null ],
      [ "timerInputClkHz", "structClockP__Config.html#a4f1a0b22542ae3dc963111cf1147a888", null ],
      [ "timerInputPreScaler", "structClockP__Config.html#add064396db18eac1a4068e9b2074cf27", null ],
      [ "usecPerTick", "structClockP__Config.html#a486a5055787ee99580a2dc985d248a5b", null ]
    ] ],
    [ "ClockP_Params", "structClockP__Params.html", [
      [ "start", "structClockP__Params.html#ae339e06c63c40995253d59265be1077f", null ],
      [ "timeout", "structClockP__Params.html#ab6b9b7154f4358a249b5545f8fd8a430", null ],
      [ "period", "structClockP__Params.html#af92c3f4d44aed9c643128e6049294f94", null ],
      [ "callback", "structClockP__Params.html#a050b0a858bbb561dd266794efb3e12e2", null ],
      [ "args", "structClockP__Params.html#af4e1c68b5325d324a3f40d900ebed4b6", null ]
    ] ],
    [ "ClockP_OBJECT_SIZE_MAX", "group__KERNEL__DPL__CLOCK.html#gab00ca501419df1c6d0b58444282e1156", null ],
    [ "ClockP_FxnCallback", "group__KERNEL__DPL__CLOCK.html#gab6ebabd2de3589d2f3055602764336a4", null ],
    [ "ClockP_init", "group__KERNEL__DPL__CLOCK.html#gab857f2e3a6f4f5537fbd19be41a35d8d", null ],
    [ "ClockP_Params_init", "group__KERNEL__DPL__CLOCK.html#ga666e9ded465c969456e6c4ef95e849f4", null ],
    [ "ClockP_construct", "group__KERNEL__DPL__CLOCK.html#ga269a53b277b945d1abdbf7b247770723", null ],
    [ "ClockP_destruct", "group__KERNEL__DPL__CLOCK.html#ga1e89644f6e22bab9026184fbe97ea6f0", null ],
    [ "ClockP_start", "group__KERNEL__DPL__CLOCK.html#gafc6e58e9f59a09db3f51bf5faabcb05c", null ],
    [ "ClockP_stop", "group__KERNEL__DPL__CLOCK.html#ga23864de82df797aa5ae6f9d79dbae77e", null ],
    [ "ClockP_isActive", "group__KERNEL__DPL__CLOCK.html#gad656f1c6ee80f43a375a5e9e0786a9e3", null ],
    [ "ClockP_setTimeout", "group__KERNEL__DPL__CLOCK.html#ga9e9856925b37c23a38b38342a749a46d", null ],
    [ "ClockP_getTimeout", "group__KERNEL__DPL__CLOCK.html#gad335017943bc236cdbf9ee1f7b9619f1", null ],
    [ "ClockP_getTicks", "group__KERNEL__DPL__CLOCK.html#gaba13f6f010af1dc91b360c6ec2c6a2ff", null ],
    [ "ClockP_usecToTicks", "group__KERNEL__DPL__CLOCK.html#ga4e558cf2f30de1d449ba53af5229ee5e", null ],
    [ "ClockP_ticksToUsec", "group__KERNEL__DPL__CLOCK.html#ga66107357427c99c759c288dfc097b355", null ],
    [ "ClockP_getTimeUsec", "group__KERNEL__DPL__CLOCK.html#ga7e8e4791754ece82b27b152d754638ca", null ],
    [ "ClockP_usleep", "group__KERNEL__DPL__CLOCK.html#ga686ba37559969d4a69af02147a9b5081", null ],
    [ "ClockP_sleep", "group__KERNEL__DPL__CLOCK.html#ga44c15f99499caf08795011fcc8b6db7b", null ]
];

==> mcu_plus_sdk_am64x_08_00_00_21_docs_only.tar.xz: mcu_plus_sdk_am64x_08_00_00_21_docs_only/docs/api_guide_am64x/group__KERNEL__DPL__CLOCK.js <==
var group__KERNEL__DPL__CLOCK =
[
    [ "ClockP_Object", "structClockP__Object.html", [
      [ "rsv", "structClockP__Object.html#a611ac2d2464c1b15a69ca5c7438da7de", null ]
    ] ],
    [ "ClockP_Config", "structClockP__Config.html", [
      [ "timerBaseAddr", "structClockP__Config.html#ad5d27f698d006879055639d843b1a917", null ],
      [ "timerHwiIntNum", "structClockP__Config.html#a2bea5ba5e3f70226fe86fa4a89f602d1", null ],
      [ "timerInputClkHz", "structClockP__Config.html#a4f1a0b22542ae3dc963111cf1147a888", null ],
      [ "timerInputPreScaler", "structClockP__Config.html#add064396db18eac1a4068e9b2074cf27", null ],
      [ "usecPerTick", "structClockP__Config.html#a486a5055787ee99580a2dc985d248a5b", null ]
    ] ],
    [ "ClockP_Params", "structClockP__Params.html", [
      [ "start", "structClockP__Params.html#ae339e06c63c40995253d59265be1077f", null ],
      [ "timeout", "structClockP__Params.html#ab6b9b7154f4358a249b5545f8fd8a430", null ],
      [ "period", "structClockP__Params.html#af92c3f4d44aed9c643128e6049294f94", null ],
      [ "callback", "structClockP__Params.html#a050b0a858bbb561dd266794efb3e12e2", null ],
      [ "args", "structClockP__Params.html#af4e1c68b5325d324a3f40d900ebed4b6", null ],
      [ "name", "structClockP__Params.html#aa569bbe76191ffc32ba1b6774002d83a", null ]
    ] ],
    [ "ClockP_OBJECT_SIZE_MAX", "group__KERNEL__DPL__CLOCK.html#gab00ca501419df1c6d0b58444282e1156", null ],
    [ "ClockP_FxnCallback", "group__KERNEL__DPL__CLOCK.html#gab6ebabd2de3589d2f3055602764336a4", null ],
    [ "ClockP_init", "group__KERNEL__DPL__CLOCK.html#gab857f2e3a6f4f5537fbd19be41a35d8d", null ],
    [ "ClockP_Params_init", "group__KERNEL__DPL__CLOCK.html#ga666e9ded465c969456e6c4ef95e849f4", null ],
    [ "ClockP_construct", "group__KERNEL__DPL__CLOCK.html#ga269a53b277b945d1abdbf7b247770723", null ],
    [ "ClockP_destruct", "group__KERNEL__DPL__CLOCK.html#ga1e89644f6e22bab9026184fbe97ea6f0", null ],
    [ "ClockP_start", "group__KERNEL__DPL__CLOCK.html#gafc6e58e9f59a09db3f51bf5faabcb05c", null ],
    [ "ClockP_stop", "group__KERNEL__DPL__CLOCK.html#ga23864de82df797aa5ae6f9d79dbae77e", null ],
    [ "ClockP_isActive", "group__KERNEL__DPL__CLOCK.html#gad656f1c6ee80f43a375a5e9e0786a9e3", null ],
    [ "ClockP_setTimeout", "group__KERNEL__DPL__CLOCK.html#ga9e9856925b37c23a38b38342a749a46d", null ],
    [ "ClockP_getTimeout", "group__KERNEL__DPL__CLOCK.html#gad335017943bc236cdbf9ee1f7b9619f1", null ],
    [ "ClockP_getTicks", "group__KERNEL__DPL__CLOCK.html#gaba13f6f010af1dc91b360c6ec2c6a2ff", null ],
    [ "ClockP_usecToTicks", "group__KERNEL__DPL__CLOCK.html#ga4e558cf2f30de1d449ba53af5229ee5e", null ],
    [ "ClockP_ticksToUsec", "group__KERNEL__DPL__CLOCK.html#ga66107357427c99c759c288dfc097b355", null ],
    [ "ClockP_getTimeUsec", "group__KERNEL__DPL__CLOCK.html#ga7e8e4791754ece82b27b152d754638ca", null ],
    [ "ClockP_usleep", "group__KERNEL__DPL__CLOCK.html#ga686ba37559969d4a69af02147a9b5081", null ],
    [ "ClockP_sleep", "group__KERNEL__DPL__CLOCK.html#ga44c15f99499caf08795011fcc8b6db7b", null ]
];
